@@ -77,7 +77,7 @@ async def get_item(client: TonlibClient, addr: str, nft_items: list, items: dict
     if items:
         if str(x['index']) in items:
             content = items[str(x['index'])]
-            print(time.time() - s)
+            # print(time.time() - s)
         else:
             content = await get(content_url)
     else:
